@@ -28,9 +28,6 @@
 #include <gio/gunixinputstream.h>
 #include <glib/gstdio.h>
 
-#include "grd-rdp-server.h"
-#include "grd-vnc-server.h"
-
 #define GRD_SERVER_PORT_RANGE 10
 
 typedef struct _GrdFdSource
@@ -167,22 +164,9 @@ grd_bind_socket (GSocketListener  *server,
                  gboolean          negotiate_port,
                  GError          **error)
 {
-  g_autofree char *message_tag = NULL;
   gboolean is_bound = FALSE;
   int i;
 
-#ifdef HAVE_RDP
-  if (GRD_IS_RDP_SERVER (server))
-    message_tag = g_strdup ("[RDP]");
-  else
-#endif
-#ifdef HAVE_VNC
-  if (GRD_IS_VNC_SERVER (server))
-    message_tag = g_strdup ("[VNC]");
-  else
-#endif
-    g_assert_not_reached ();
-
   if (!negotiate_port)
     {
       is_bound = g_socket_listener_add_inet_port (server,
@@ -204,8 +188,8 @@ grd_bind_socket (GSocketListener  *server,
                                                   &local_error);
       if (local_error)
         {
-          g_debug ("%s Server could not be bound to TCP port %hu: %s",
-                   message_tag, port, local_error->message);
+          g_debug ("\tServer could not be bound to TCP port %hu: %s",
+                   port, local_error->message);
         }
 
       if (is_bound)
@@ -220,7 +204,7 @@ grd_bind_socket (GSocketListener  *server,
 out:
   if (is_bound)
     {
-      g_debug ("%s Server bound to TCP port %hu", message_tag, port);
+      g_debug ("\tServer bound to TCP port %hu", port);
       *selected_port = port;
     }
 
@@ -340,3 +324,140 @@ grd_test_fd (int         fd,
 
   return TRUE;
 }
+
+gboolean
+grd_toggle_systemd_unit (gboolean   enabled,
+                         GError   **error)
+{
+
+  g_autoptr (GStrvBuilder) builder = NULL;
+  g_autofree char *error_output = NULL;
+  g_auto (GStrv) new_argv = NULL;
+  g_autofree char *pid = NULL;
+  int wait_status;
+  gboolean success;
+
+  builder = g_strv_builder_new ();
+
+  g_strv_builder_add (builder,
+                      GRD_LIBEXEC_DIR "/gnome-remote-desktop-enable-service");
+  pid = g_strdup_printf ("%d", getppid ());
+  g_strv_builder_add (builder, pid);
+  if (enabled)
+    g_strv_builder_add (builder, "true");
+  else
+    g_strv_builder_add (builder, "false");
+
+  new_argv = g_strv_builder_end (builder);
+
+  success = g_spawn_sync (NULL,
+                          new_argv,
+                          NULL,
+                          G_SPAWN_SEARCH_PATH |
+                          G_SPAWN_CHILD_INHERITS_STDOUT,
+                          NULL,
+                          NULL,
+                          NULL,
+                          &error_output,
+                          &wait_status,
+                          error);
+  if (!success)
+    return FALSE;
+
+  if (!WIFEXITED (wait_status) || WEXITSTATUS (wait_status) != 0)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                   "Could not %s system service:\n%s",
+                   enabled? "enable" : "disable",
+                   error_output);
+      return FALSE;
+    }
+
+  return success;
+}
+
+gboolean
+grd_systemd_get_unit (GBusType     bus_type,
+                      const char  *unit,
+                      GDBusProxy **proxy,
+                      GError     **error)
+{
+  g_autoptr (GDBusProxy) manager_proxy = NULL;
+  g_autoptr (GDBusProxy) unit_proxy = NULL;
+  g_autoptr (GVariant) result = NULL;
+  g_autofree char *object_path = NULL;
+
+  manager_proxy = g_dbus_proxy_new_for_bus_sync (
+                    bus_type,
+                    G_DBUS_PROXY_FLAGS_NONE,
+                    NULL,
+                    "org.freedesktop.systemd1",
+                    "/org/freedesktop/systemd1",
+                    "org.freedesktop.systemd1.Manager",
+                    NULL,
+                    error);
+  if (!manager_proxy)
+    return FALSE;
+
+  result = g_dbus_proxy_call_sync (manager_proxy,
+                                   "LoadUnit",
+                                   g_variant_new ("(s)", unit),
+                                   G_DBUS_CALL_FLAGS_NONE,
+                                   -1,
+                                   NULL,
+                                   error);
+  if (!result)
+    return FALSE;
+
+  g_variant_get (result, "(o)", &object_path);
+
+  unit_proxy = g_dbus_proxy_new_for_bus_sync (bus_type,
+                                              G_DBUS_PROXY_FLAGS_NONE,
+                                              NULL,
+                                              "org.freedesktop.systemd1",
+                                              object_path,
+                                              "org.freedesktop.systemd1.Unit",
+                                              NULL,
+                                              error);
+  if (!unit_proxy)
+    return FALSE;
+
+  *proxy = g_steal_pointer (&unit_proxy);
+  return TRUE;
+}
+
+gboolean
+grd_systemd_unit_get_active_state (GDBusProxy                 *unit_proxy,
+                                   GrdSystemdUnitActiveState  *active_state,
+                                   GError                    **error)
+{
+  g_autoptr (GVariant) result = NULL;
+  g_autofree char *res_active_state = NULL;
+
+  result = g_dbus_proxy_get_cached_property (unit_proxy, "ActiveState");
+  if (!result)
+    {
+      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_PROPERTY,
+                   "An error occurred while getting the ActiveState property");
+      return FALSE;
+    }
+
+  g_variant_get (result, "s", &res_active_state);
+
+  if (g_str_equal (res_active_state, "active"))
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_ACTIVE;
+  else if (g_str_equal (res_active_state, "reloading"))
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_RELOADING;
+  else if (g_str_equal (res_active_state, "inactive"))
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_INACTIVE;
+  else if (g_str_equal (res_active_state, "failed"))
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_FAILED;
+  else if (g_str_equal (res_active_state, "activating"))
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_ACTIVATING;
+  else if (g_str_equal (res_active_state, "deactivating"))
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_DEACTIVATING;
+  else
+    *active_state = GRD_SYSTEMD_UNIT_ACTIVE_STATE_UNKNOWN;
+
+  return TRUE;
+}
